[aur-dev] [PATCH/RFC] Add support for .SRCINFO

archlinux at cryptocrack.de archlinux at cryptocrack.de
Tue Nov 18 22:55:10 UTC 2014


From: Lukas Fleischer <archlinux at cryptocrack.de>

pacman officially supports .SRCINFO since commit 6029a77 (makepkg:
introduce .SRCINFO files for source packages, 2014-11-08).

Signed-off-by: Lukas Fleischer <archlinux at cryptocrack.de>
---
 web/html/pkgsubmit.php | 7 ++++---
 1 file changed, 4 insertions(+), 3 deletions(-)

diff --git a/web/html/pkgsubmit.php b/web/html/pkgsubmit.php
index be9220e..d8df290 100644
--- a/web/html/pkgsubmit.php
+++ b/web/html/pkgsubmit.php
@@ -81,7 +81,7 @@ if ($uid):
 		if (!$error) {
 			$tar = new Archive_Tar($_FILES['pfile']['tmp_name']);
 
 			/* Extract PKGBUILD and .AURINFO into a string. */
 			$pkgbuild_raw = $srcinfo_raw = '';
 			$dircount = 0;
 			foreach ($tar->listContent() as $tar_file) {
@@ -94,7 +94,8 @@ if ($uid):
 						break;
 					} elseif (substr($tar_file['filename'], -9) == '/PKGBUILD') {
 						$pkgbuild_raw = $tar->extractInString($tar_file['filename']);
-					} elseif (substr($tar_file['filename'], -9) == '/.AURINFO') {
+					} elseif (substr($tar_file['filename'], -9) == '/.AURINFO' ||
+						  substr($tar_file['filename'], -9) == '/.SRCINFO') {
 						$srcinfo_raw = $tar->extractInString($tar_file['filename']);
 					}
 				} elseif ($tar_file['typeflag'] == 5) {
@@ -127,7 +128,7 @@ if ($uid):
 			}
 		}
 
 		/* Parse .AURINFO and extract meta data. */
 		$pkgbase_info = array();
 		$pkginfo = array();
 		$section_info = array();
@@ -81,7 +81,7 @@ if ($uid):
 			$tar = new Archive_Tar($_FILES['pfile']['tmp_name']);
 
-			/* Extract PKGBUILD and .AURINFO into a string. */
+			/* Extract PKGBUILD and .SRCINFO into a string. */
 			$pkgbuild_raw = $srcinfo_raw = '';
 			$dircount = 0;
@@ -127,7 +128,7 @@ if ($uid):
 		}
 
-		/* Parse .AURINFO and extract meta data. */
+		/* Parse .SRCINFO and extract meta data. */
 		$pkgbase_info = array();
 		$pkginfo = array();
-- 
2.1.3


More information about the aur-dev mailing list